==> OpenMesh-2.2.tar.bz2: OpenMesh-2.2/Documentation/mesh_docu.js <==
var mesh_docu =
[
    [ "Features and Goals of OpenMesh", "mesh_features.html", null ],
    [ "The Halfedge Data Structure", "mesh_hds.html", null ],
    [ "Mesh Iterators and Circulators", "mesh_iterators.html", [
      [ "Iterators", "mesh_iterators.html#it_iters", null ],
      [ "How to use iterators in OpenMesh", "mesh_iterators.html#it_iters_h", null ],
      [ "Skipping Iterators", "mesh_iterators.html#it_iters_skipping", null ],
      [ "Circulators", "mesh_iterators.html#it_circs", null ],
      [ "How to use circulators in OpenMesh", "mesh_iterators.html#it_circs_h", null ]
    ] ],
    [ "How to navigate on a mesh", "mesh_navigation.html", [
      [ "Overview", "mesh_navigation.html#nav_overview", null ],
      [ "Introduction", "mesh_navigation.html#nav_intro", null ],
      [ "Navigating over halfedges", "mesh_navigation.html#nav_he", null ],
      [ "Mesh boundaries", "mesh_navigation.html#nav_bound", null ],
      [ "Using incoming and outgoing halfedges", "mesh_navigation.html#nav_io", null ],
      [ "Using opposite halfedges", "mesh_navigation.html#nav_opposite", null ]
    ] ],
    [ "Read and write meshes from files", "mesh_io.html", [
      [ "Step 1 - IOManager quick start", "mesh_io.html#mesh_io_quick", null ],
      [ "Step 2 - The theory behind IOManager", "mesh_io.html#mesh_io_theory", null ],
      [ "Step 3 - How to extend IOManager", "mesh_io.html#mesh_io_extend", [
        [ "Adding support for a new file format", "mesh_io.html#mesh_io_extend_fileformat", null ],
        [ "Adding support for a new data structure", "mesh_io.html#mesh_io_extend_datastruct", null ]
      ] ]
    ] ],
    [ "Some basic operations: Flipping and collapsing edges", "mesh_operations.html", [
      [ "Flipping edges in triangle meshes", "mesh_operations.html#op_flip", null ],
      [ "Collapsing edges", "mesh_operations.html#op_collapse", null ]
    ] ],
    [ "Conceptual Class Hierarchy", "mesh_hierarchy.html", [
      [ "Building the kernel", "mesh_hierarchy.html#ch_kernel", null ],
      [ "Building the mesh", "mesh_hierarchy.html#ch_complete", null ]
    ] ],
    [ "Specifying your MyMesh", "mesh_type.html", [
      [ "Polygonal or Triangle Mesh?", "mesh_type.html#sec_select_face_type", null ],
      [ "Choosing the right kernel", "mesh_type.html#sec_select_kernel", null ],
      [ "Mesh Traits", "mesh_type.html#sec_select_traits", [
        [ "Changing the Point type", "mesh_type.html#sec_change_point", null ],
        [ "Adding Predefined Attributes", "mesh_type.html#sec_add_attributes", null ],
        [ "Adding User-Defined Elements", "mesh_type.html#sec_add_traits", null ],
        [ "Using traits defined by algorithms", "mesh_type.html#sec_algo_traits", null ]
      ] ],
      [ "Dynamic Properties", "mesh_type.html#sec_properties", null ],
      [ "Final Implementation Example", "mesh_type.html#sec_traits_example", null ]
    ] ]
];

==> OpenMesh-2.3.1.tar.bz2: OpenMesh-2.3.1/Documentation/mesh_docu.js <==
var mesh_docu =
[
    [ "Features and Goals of OpenMesh", "mesh_features.html", null ],
    [ "The Halfedge Data Structure", "mesh_hds.html", null ],
    [ "Mesh Iterators and Circulators", "mesh_iterators.html", [
      [ "Iterators", "mesh_iterators.html#it_iters", [
        [ "Deleted Elements", "mesh_iterators.html#deletedElements", null ]
      ] ],
      [ "How to use iterators in OpenMesh", "mesh_iterators.html#it_iters_h", null ],
      [ "Skipping Iterators", "mesh_iterators.html#it_iters_skipping", null ],
      [ "Circulators", "mesh_iterators.html#it_circs", null ],
      [ "How to use circulators in OpenMesh", "mesh_iterators.html#it_circs_h", null ]
    ] ],
    [ "How to navigate on a mesh", "mesh_navigation.html", [
      [ "Overview", "mesh_navigation.html#nav_overview", null ],
      [ "Introduction", "mesh_navigation.html#nav_intro", null ],
      [ "Navigating over halfedges", "mesh_navigation.html#nav_he", null ],
      [ "Mesh boundaries", "mesh_navigation.html#nav_bound", null ],
      [ "Using incoming and outgoing halfedges", "mesh_navigation.html#nav_io", null ],
      [ "Using opposite halfedges", "mesh_navigation.html#nav_opposite", null ]
    ] ],
    [ "Read and write meshes from files", "mesh_io.html", [
      [ "Step 1 - IOManager quick start", "mesh_io.html#mesh_io_quick", null ],
      [ "Step 2 - The theory behind IOManager", "mesh_io.html#mesh_io_theory", null ],
      [ "Step 3 - How to extend IOManager", "mesh_io.html#mesh_io_extend", [
        [ "Adding support for a new file format", "mesh_io.html#mesh_io_extend_fileformat", null ],
        [ "Adding support for a new data structure", "mesh_io.html#mesh_io_extend_datastruct", null ]
      ] ]
    ] ],
    [ "Some basic operations: Flipping and collapsing edges", "mesh_operations.html", [
      [ "Flipping edges in triangle meshes", "mesh_operations.html#op_flip", null ],
      [ "Collapsing edges", "mesh_operations.html#op_collapse", null ]
    ] ],
    [ "Conceptual Class Hierarchy", "mesh_hierarchy.html", [
      [ "Building the kernel", "mesh_hierarchy.html#ch_kernel", null ],
      [ "Building the mesh", "mesh_hierarchy.html#ch_complete", null ]
    ] ],
    [ "Specifying your MyMesh", "mesh_type.html", [
      [ "Polygonal or Triangle Mesh?", "mesh_type.html#sec_select_face_type", null ],
      [ "Choosing the right kernel", "mesh_type.html#sec_select_kernel", null ],
      [ "Mesh Traits", "mesh_type.html#sec_select_traits", [
        [ "Changing the Point type", "mesh_type.html#sec_change_point", null ],
        [ "Adding Predefined Attributes", "mesh_type.html#sec_add_attributes", null ],
        [ "Adding User-Defined Elements", "mesh_type.html#sec_add_traits", null ],
        [ "Using traits defined by algorithms", "mesh_type.html#sec_algo_traits", null ]
      ] ],
      [ "Dynamic Properties", "mesh_type.html#sec_properties", null ],
      [ "Final Implementation Example", "mesh_type.html#sec_traits_example", null ]
    ] ]
];
